package io.gitlab.jfronny.commons.logger;

import org.slf4j.Logger;
import org.slf4j.Marker;

/**
 * Logger implementation that logs to multiple loggers at once.
 */
public class CompoundLogger implements Logger {
    private final String name;
    private final Logger[] loggers;

    public CompoundLogger(String name, Logger[] loggers) {
        this.name = name;
        this.loggers = loggers;
    }

    @Override
    public String getName() {
        return name;
    }

    @Override
    public boolean isTraceEnabled() {
        for (Logger logger : loggers) {
            if (logger.isTraceEnabled()) return true;
        }
        return false;
    }

    @Override
    public void trace(String msg) {
        for (Logger logger : loggers) {
            logger.trace(msg);
        }
    }

    @Override
    public void trace(String format, Object arg) {
        for (Logger logger : loggers) {
            logger.trace(format, arg);
        }
    }

    @Override
    public void trace(String format, Object arg1, Object arg2) {
        for (Logger logger : loggers) {
            logger.trace(format, arg1, arg2);
        }
    }

    @Override
    public void trace(String format, Object... arguments) {
        for (Logger logger : loggers) {
            logger.trace(format, arguments);
        }
    }

    @Override
    public void trace(String msg, Throwable t) {
        for (Logger logger : loggers) {
            logger.trace(msg, t);
        }
    }

    @Override
    public boolean isTraceEnabled(Marker marker) {
        for (Logger logger : loggers) {
            if (logger.isTraceEnabled(marker)) return true;
        }
        return false;
    }

    @Override
    public void trace(Marker marker, String msg) {
        for (Logger logger : loggers) {
            logger.trace(marker, msg);
        }
    }

    @Override
    public void trace(Marker marker, String format, Object arg) {
        for (Logger logger : loggers) {
            logger.trace(marker, format, arg);
        }
    }

    @Override
    public void trace(Marker marker, String format, Object arg1, Object arg2) {
        for (Logger logger : loggers) {
            logger.trace(marker, format, arg1, arg2);
        }
    }

    @Override
    public void trace(Marker marker, String format, Object... argArray) {
        for (Logger logger : loggers) {
            logger.trace(marker, format, argArray);
        }
    }

    @Override
    public void trace(Marker marker, String msg, Throwable t) {
        for (Logger logger : loggers) {
            logger.trace(marker, msg, t);
        }
    }

    @Override
    public boolean isDebugEnabled() {
        for (Logger logger : loggers) {
            if (logger.isDebugEnabled()) return true;
        }
        return false;
    }

    @Override
    public void debug(String msg) {
        for (Logger logger : loggers) {
            logger.debug(msg);
        }
    }

    @Override
    public void debug(String format, Object arg) {
        for (Logger logger : loggers) {
            logger.debug(format, arg);
        }
    }

    @Override
    public void debug(String format, Object arg1, Object arg2) {
        for (Logger logger : loggers) {
            logger.debug(format, arg1, arg2);
        }
    }

    @Override
    public void debug(String format, Object... arguments) {
        for (Logger logger : loggers) {
            logger.trace(format, arguments);
        }
    }

    @Override
    public void debug(String msg, Throwable t) {
        for (Logger logger : loggers) {
            logger.debug(msg, t);
        }
    }

    @Override
    public boolean isDebugEnabled(Marker marker) {
        for (Logger logger : loggers) {
            if (logger.isDebugEnabled(marker)) return true;
        }
        return false;
    }

    @Override
    public void debug(Marker marker, String msg) {
        for (Logger logger : loggers) {
            logger.debug(marker, msg);
        }
    }

    @Override
    public void debug(Marker marker, String format, Object arg) {
        for (Logger logger : loggers) {
            logger.debug(marker, format, arg);
        }
    }

    @Override
    public void debug(Marker marker, String format, Object arg1, Object arg2) {
        for (Logger logger : loggers) {
            logger.debug(marker, format, arg1, arg2);
        }
    }

    @Override
    public void debug(Marker marker, String format, Object... arguments) {
        for (Logger logger : loggers) {
            logger.debug(marker, format, arguments);
        }
    }

    @Override
    public void debug(Marker marker, String msg, Throwable t) {
        for (Logger logger : loggers) {
            logger.debug(marker, msg, t);
        }
    }

    @Override
    public boolean isInfoEnabled() {
        for (Logger logger : loggers) {
            if (logger.isInfoEnabled()) return true;
        }
        return false;
    }

    @Override
    public void info(String msg) {
        for (Logger logger : loggers) {
            logger.info(msg);
        }
    }

    @Override
    public void info(String format, Object arg) {
        for (Logger logger : loggers) {
            logger.info(format, arg);
        }
    }

    @Override
    public void info(String format, Object arg1, Object arg2) {
        for (Logger logger : loggers) {
            logger.info(format, arg1, arg2);
        }
    }

    @Override
    public void info(String format, Object... arguments) {
        for (Logger logger : loggers) {
            logger.info(format, arguments);
        }
    }

    @Override
    public void info(String msg, Throwable t) {
        for (Logger logger : loggers) {
            logger.info(msg, t);
        }
    }

    @Override
    public boolean isInfoEnabled(Marker marker) {
        for (Logger logger : loggers) {
            if (logger.isInfoEnabled(marker)) return true;
        }
        return false;
    }

    @Override
    public void info(Marker marker, String msg) {
        for (Logger logger : loggers) {
            logger.info(marker, msg);
        }
    }

    @Override
    public void info(Marker marker, String format, Object arg) {
        for (Logger logger : loggers) {
            logger.info(marker, format, arg);
        }
    }

    @Override
    public void info(Marker marker, String format, Object arg1, Object arg2) {
        for (Logger logger : loggers) {
            logger.info(marker, format, arg1, arg2);
        }
    }

    @Override
    public void info(Marker marker, String format, Object... arguments) {
        for (Logger logger : loggers) {
            logger.info(marker, format, arguments);
        }
    }

    @Override
    public void info(Marker marker, String msg, Throwable t) {
        for (Logger logger : loggers) {
            logger.info(marker, msg, t);
        }
    }

    @Override
    public boolean isWarnEnabled() {
        for (Logger logger : loggers) {
            if (logger.isWarnEnabled()) return true;
        }
        return false;
    }

    @Override
    public void warn(String msg) {
        for (Logger logger : loggers) {
            logger.warn(msg);
        }
    }

    @Override
    public void warn(String format, Object arg) {
        for (Logger logger : loggers) {
            logger.warn(format, arg);
        }
    }

    @Override
    public void warn(String format, Object... arguments) {
        for (Logger logger : loggers) {
            logger.warn(format, arguments);
        }
    }

    @Override
    public void warn(String format, Object arg1, Object arg2) {
        for (Logger logger : loggers) {
            logger.warn(format, arg1, arg2);
        }
    }

    @Override
    public void warn(String msg, Throwable t) {
        for (Logger logger : loggers) {
            logger.warn(msg, t);
        }
    }

    @Override
    public boolean isWarnEnabled(Marker marker) {
        for (Logger logger : loggers) {
            if (logger.isWarnEnabled(marker)) return true;
        }
        return false;
    }

    @Override
    public void warn(Marker marker, String msg) {
        for (Logger logger : loggers) {
            logger.warn(marker, msg);
        }
    }

    @Override
    public void warn(Marker marker, String format, Object arg) {
        for (Logger logger : loggers) {
            logger.warn(marker, format, arg);
        }
    }

    @Override
    public void warn(Marker marker, String format, Object arg1, Object arg2) {
        for (Logger logger : loggers) {
            logger.warn(marker, format, arg1, arg2);
        }
    }

    @Override
    public void warn(Marker marker, String format, Object... arguments) {
        for (Logger logger : loggers) {
            logger.warn(marker, format, arguments);
        }
    }

    @Override
    public void warn(Marker marker, String msg, Throwable t) {
        for (Logger logger : loggers) {
            logger.warn(marker, msg, t);
        }
    }

    @Override
    public boolean isErrorEnabled() {
        for (Logger logger : loggers) {
            if (logger.isErrorEnabled()) return true;
        }
        return false;
    }

    @Override
    public void error(String msg) {
        for (Logger logger : loggers) {
            logger.error(msg);
        }
    }

    @Override
    public void error(String format, Object arg) {
        for (Logger logger : loggers) {
            logger.error(format, arg);
        }
    }

    @Override
    public void error(String format, Object arg1, Object arg2) {
        for (Logger logger : loggers) {
            logger.error(format, arg1, arg2);
        }
    }

    @Override
    public void error(String format, Object... arguments) {
        for (Logger logger : loggers) {
            logger.error(format, arguments);
        }
    }

    @Override
    public void error(String msg, Throwable t) {
        for (Logger logger : loggers) {
            logger.error(msg, t);
        }
    }

    @Override
    public boolean isErrorEnabled(Marker marker) {
        for (Logger logger : loggers) {
            if (logger.isErrorEnabled(marker)) return true;
        }
        return false;
    }

    @Override
    public void error(Marker marker, String msg) {
        for (Logger logger : loggers) {
            logger.error(marker, msg);
        }
    }

    @Override
    public void error(Marker marker, String format, Object arg) {
        for (Logger logger : loggers) {
            logger.error(marker, format, arg);
        }
    }

    @Override
    public void error(Marker marker, String format, Object arg1, Object arg2) {
        for (Logger logger : loggers) {
            logger.error(marker, format, arg1, arg2);
        }
    }

    @Override
    public void error(Marker marker, String format, Object... arguments) {
        for (Logger logger : loggers) {
            logger.error(marker, format, arguments);
        }
    }

    @Override
    public void error(Marker marker, String msg, Throwable t) {
        for (Logger logger : loggers) {
            logger.error(marker, msg, t);
        }
    }
}
